@@ -1,12 +1,12 @@
 package Sah::Schema::Sah;
 
+our $DATE = '2016-05-12'; # DATE
+our $VERSION = '0.9.40'; # VERSION
+
 use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.9.39'; # VERSION
-our $DATE = '2015-09-09'; # DATE
-
 our %SCHEMAS;
 
 $SCHEMAS{sah_type_name} = ['str' => {
@@ -17,7 +17,7 @@ $SCHEMAS{sah_str_schema} = ['str' => {
     match => '\A[A-Za-z][A-Za-z0-9_]*(::[A-Za-z][A-Za-z0-9_]*)*\*?\z',
 }];
 
-$SCHEMAS{sah_clause_name} = undef; # TODO
+#$SCHEMAS{sah_clause_name} = undef; # TODO
 
 $SCHEMAS{sah_clause_set} = [defhash => {
     # tmp
@@ -78,7 +78,25 @@ Sah::Schema::Sah - Sah schemas for Sah schema
 
 =head1 VERSION
 
-This document describes version 0.9.39 of Sah::Schema::Sah (from Perl distribution Sah), released on 2015-09-09.
+This document describes version 0.9.40 of Sah::Schema::Sah (from Perl distribution Sah), released on 2016-05-12.
+
+=head1 SAH SCHEMAS
+
+=over
+
+=item * sah_array_schema
+
+=item * sah_clause_set
+
+=item * sah_extras
+
+=item * sah_schema
+
+=item * sah_str_schema
+
+=item * sah_type_name
+
+=back
 
 =head1 HOMEPAGE
 
@@ -96,13 +114,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Sah> - specification
+
+L<Data::Sah>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
